@@ -28,7 +28,6 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libmate-desktop/mate-aboutdialog.h>
 #include <mate-panel-applet.h>
 
 #include "drive-list.h"
@@ -80,11 +79,7 @@ static void
 change_background (MatePanelApplet               *applet,
 		   MatePanelAppletBackgroundType  type,
 		   GdkColor                  *colour,
-#if GTK_CHECK_VERSION (3, 0, 0)
 		   cairo_pattern_t           *pattern,
-#else
-		   GdkPixmap                 *pixmap,
-#endif
 		   DriveList                 *drivelist)
 {
     switch (type) {
@@ -107,15 +102,19 @@ display_about_dialog (GtkAction *action,
 	"James Henstridge <jamesh@canonical.com>",
 	NULL
     };
+    char copyright[] = \
+	"Copyright \xc2\xa9 2012-2017 MATE developers\n"
+	"Copyright \xC2\xA9 2004 Canonical Ltd";
+
     const gchar *documenters[] = {
 	"Dan Mueth <muet@alumni.uchicago.edu>",
 	"John Fleck <jfleck@inkstain.net>",
 	NULL
     };
 
-    mate_show_about_dialog (NULL,
+    gtk_show_about_dialog (NULL,
 	"version",     VERSION,
-	"copyright",   "Copyright \xC2\xA9 2004 Canonical Ltd",
+	"copyright",   copyright,
 	"comments",    _("Applet for mounting and unmounting block volumes."),
 	"authors",     authors,
 	"documenters", documenters,
