@@ -41,11 +41,6 @@
 
 #define MAX_CONSECUTIVE_FAULTS (3)
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#endif
-
 static void about_cb (GtkAction      *action,
 		      MateWeatherApplet *gw_applet)
 {
@@ -152,7 +147,8 @@ static void place_widgets (MateWeatherApplet *gw_applet)
     gw_applet->image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_BUTTON); 
 
     if (icon_name != NULL) {
-        gtk_widget_size_request(gw_applet->image, &req);
+        gtk_widget_show (gw_applet->image);
+        gtk_widget_get_preferred_size (gw_applet->image, &req, NULL);
         if (horizontal)
             total_size += req.height;
         else
@@ -168,7 +164,8 @@ static void place_widgets (MateWeatherApplet *gw_applet)
         gtk_label_set_text(GTK_LABEL(gw_applet->label), temp);
 
     /* Check the label size to determine box layout */
-    gtk_widget_size_request(gw_applet->label, &req);
+    gtk_widget_show (gw_applet->label);
+    gtk_widget_get_preferred_size (gw_applet->label, &req, NULL);
     if (horizontal)
         total_size += req.height;
     else
@@ -179,13 +176,13 @@ static void place_widgets (MateWeatherApplet *gw_applet)
         gtk_widget_destroy (gw_applet->box);
     
     if (horizontal && (total_size <= panel_size))
-        gw_applet->box = gtk_vbox_new(FALSE, 0);
+        gw_applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     else if (horizontal && (total_size > panel_size))
-        gw_applet->box = gtk_hbox_new(FALSE, 2);
+        gw_applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
     else if (!horizontal && (total_size <= panel_size))
-        gw_applet->box = gtk_hbox_new(FALSE, 2);
+        gw_applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
     else 
-        gw_applet->box = gtk_vbox_new(FALSE, 0);
+        gw_applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
     /* Rebuild the applet it's visual area */
     gtk_container_add (GTK_CONTAINER (gw_applet->container), gw_applet->box);
@@ -397,7 +394,7 @@ gint timeout_cb (gpointer data)
     MateWeatherApplet *gw_applet = (MateWeatherApplet *)data;
 	
     mateweather_update(gw_applet);
-    return 0;  /* Do not repeat timeout (will be re-set by mateweather_update) */
+    return 0;  /* Do not repeat timeout (will be reset by mateweather_update) */
 }
 
 static void
@@ -509,7 +506,7 @@ gint suncalc_timeout_cb (gpointer data)
 {
     WeatherInfo *info = ((MateWeatherApplet *)data)->mateweather_info;
     update_finish(info, data);
-    return 0;  /* Do not repeat timeout (will be re-set by update_finish) */
+    return 0;  /* Do not repeat timeout (will be reset by update_finish) */
 }
 
 
