@@ -25,6 +25,7 @@
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE 1
 #include <libwnck/libwnck.h>
 #include <string.h>
+#include <sys/stat.h>
 
 #include <gtksourceview/gtksource.h>
 
@@ -291,6 +292,9 @@ stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 
 	g_object_unref(builder);
 
+	g_signal_connect_after (note->w_body, "button-press-event",
+	                        G_CALLBACK (gtk_true), note);
+
 	g_signal_connect (gtk_text_view_get_buffer(GTK_TEXT_VIEW(note->w_body)),
 			  "changed",
 			  G_CALLBACK (buffer_changed), note);
@@ -778,7 +782,10 @@ stickynotes_save_now (void)
 
 	/* The XML file is $HOME/.config/mate/stickynotes-applet, most probably */
 	{
-			gchar* file = g_build_filename(g_get_user_config_dir(), "mate", "stickynotes-applet.xml", NULL);
+		gchar* path = g_build_filename(g_get_user_config_dir(), "mate", NULL);
+		gchar* file = g_build_filename(path, "stickynotes-applet.xml", NULL);
+		g_mkdir_with_parents(path, S_IRWXU);
+		g_free(path);
 
 		xmlSaveFormatFile(file, doc, 1);
 
