@@ -30,7 +30,6 @@
 #include <gtk/gtk.h>
 
 #include <libnotify/notify.h>
-#include <libmate-desktop/mate-aboutdialog.h>
 
 #include <mate-panel-applet.h>
 #include <mate-panel-applet-gsettings.h>
@@ -46,10 +45,6 @@
 #define SHOW_NOTIFICATION_KEY   "show-notification"
 #define SHOW_DIALOG_KEY         "show-dialog"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#endif
-
 typedef struct
 {
     MatePanelApplet   *applet;
@@ -253,9 +248,13 @@ timer_about_callback (GtkAction *action, TimerApplet *applet)
 {
     const char* authors[] = { "Stefano Karapetsas <stefano@karapetsas.com>", NULL };
 
-    mate_show_about_dialog(NULL,
+    char copyright[] = \
+        "Copyright \xc2\xa9 2015-2017 MATE developers\n"
+        "Copyright \xc2\xa9 2014 Stefano Karapetsas";
+
+    gtk_show_about_dialog(NULL,
                           "version", VERSION,
-                          "copyright", "Copyright © 2014 Stefano Karapetsas",
+                          "copyright", copyright,
                           "authors", authors,
                           "comments", _("Start a timer and receive a notification when it is finished"),
                           "translator-credits", _("translator-credits"),
@@ -281,7 +280,7 @@ static void
 timer_preferences_callback (GtkAction *action, TimerApplet *applet)
 {
     GtkDialog *dialog;
-    GtkTable *table;
+    GtkGrid *grid;
     GtkWidget *widget;
     gint duration, hours, minutes, seconds;
 
@@ -296,9 +295,9 @@ timer_preferences_callback (GtkAction *action, TimerApplet *applet)
                                                      GTK_STOCK_CLOSE,
                                                      GTK_RESPONSE_CLOSE,
                                                      NULL));
-    table = GTK_TABLE (gtk_table_new (6, 2, FALSE));
-    gtk_table_set_row_spacings (table, 12);
-    gtk_table_set_col_spacings (table, 12);
+    grid = GTK_GRID (gtk_grid_new ());
+    gtk_grid_set_row_spacing (grid, 12);
+    gtk_grid_set_column_spacing (grid, 12);
 
     gtk_window_set_default_size (GTK_WINDOW (dialog), 350, 150);
     gtk_container_set_border_width (GTK_CONTAINER (dialog), 10);
@@ -310,14 +309,10 @@ timer_preferences_callback (GtkAction *action, TimerApplet *applet)
 #else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
 #endif
-    gtk_table_attach (table, widget, 1, 2, 0, 1,
-                      GTK_FILL, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 1, 0, 1, 1);
 
     widget = gtk_entry_new ();
-    gtk_table_attach (table, widget, 2, 3, 0, 1,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 2, 0, 1, 1);
     g_settings_bind (applet->settings, NAME_KEY, widget, "text", G_SETTINGS_BIND_DEFAULT);
 
     widget = gtk_label_new (_("Hours:"));
@@ -327,15 +322,11 @@ timer_preferences_callback (GtkAction *action, TimerApplet *applet)
 #else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
 #endif
-    gtk_table_attach (table, widget, 1, 2, 1, 2,
-                      GTK_FILL, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 1, 1, 1, 1);
 
     widget = gtk_spin_button_new_with_range (0.0, 100.0, 1.0);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), hours);
-    gtk_table_attach (table, widget, 2, 3, 1, 2,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 2, 1, 1, 1);
     applet->hours = GTK_SPIN_BUTTON (widget);
     g_signal_connect (widget, "value-changed", G_CALLBACK (timer_spin_button_value_changed), applet);
 
@@ -346,15 +337,11 @@ timer_preferences_callback (GtkAction *action, TimerApplet *applet)
 #else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
 #endif
-    gtk_table_attach (table, widget, 1, 2, 2, 3,
-                      GTK_FILL, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 1, 2, 1, 1);
 
     widget = gtk_spin_button_new_with_range (0.0, 59.0, 1.0);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), minutes);
-    gtk_table_attach (table, widget, 2, 3, 2, 3,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 2, 2, 1, 1);;
     applet->minutes = GTK_SPIN_BUTTON (widget);
     g_signal_connect (widget, "value-changed", G_CALLBACK (timer_spin_button_value_changed), applet);
 
@@ -365,31 +352,23 @@ timer_preferences_callback (GtkAction *action, TimerApplet *applet)
 #else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
 #endif
-    gtk_table_attach (table, widget, 1, 2, 3, 4,
-                      GTK_FILL, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 1, 3, 1, 1);
 
     widget = gtk_spin_button_new_with_range (0.0, 59.0, 1.0);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), seconds);
-    gtk_table_attach (table, widget, 2, 3, 3, 4,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 2, 3, 1, 1);
     applet->seconds = GTK_SPIN_BUTTON (widget);
     g_signal_connect (widget, "value-changed", G_CALLBACK (timer_spin_button_value_changed), applet);
 
     widget = gtk_check_button_new_with_label (_("Show notification popup"));
-    gtk_table_attach (table, widget, 2, 3, 4, 5,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 2, 4, 1, 1);
     g_settings_bind (applet->settings, SHOW_NOTIFICATION_KEY, widget, "active", G_SETTINGS_BIND_DEFAULT);
 
     widget = gtk_check_button_new_with_label (_("Show dialog"));
-    gtk_table_attach (table, widget, 2, 3, 5, 6,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 2, 5, 1, 1);
     g_settings_bind (applet->settings, SHOW_DIALOG_KEY, widget, "active", G_SETTINGS_BIND_DEFAULT);
 
-    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)), GTK_WIDGET (table), TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)), GTK_WIDGET (grid), TRUE, TRUE, 0);
 
     g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), dialog);
 
@@ -423,7 +402,7 @@ timer_applet_fill (MatePanelApplet* applet_widget)
     applet->active = FALSE;
     applet->pause = FALSE;
 
-    applet->box = GTK_BOX (gtk_hbox_new (FALSE, 0));
+    applet->box = GTK_BOX (gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0));
     applet->image = GTK_IMAGE (gtk_image_new_from_icon_name (APPLET_ICON, GTK_ICON_SIZE_BUTTON));
     applet->pause_image = GTK_IMAGE (gtk_image_new_from_icon_name (GTK_STOCK_MEDIA_PAUSE, GTK_ICON_SIZE_BUTTON));
     applet->label = GTK_LABEL (gtk_label_new (""));
